# -*- coding: utf-8 -*-
##############################################################################
#
#    OpenERP, Open Source Management Solution
#    Copyright (C) 20010 Akretion LDTA (<http://www.akretion.com>).
#    @author Raphaël Valyi
#
#    This program is free software: you can redistribute it and/or modify
#    it under the terms of the GNU Affero General Public License as
#    published by the Free Software Foundation, either version 3 of the
#    License, or (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU Affero General Public License for more details.
#
#    You should have received a copy of the GNU Affero General Public License
#    along with this program.  If not, see <http://www.gnu.org/licenses/>.
#
##############################################################################

import netsvc
import time

from osv import osv,fields
from tools.translate import _

class stock_consignation(osv.osv_memory):
    _inherit = 'stock.return.picking'
    _name = 'stock.consignation'
    
    _columns = {
        'journal_id': fields.many2one('account.journal', 'Diário de Destino', required=True),
        'group': fields.boolean("Agrupar por Parceiro"),
     }

    def _create_returns(self, cr, uid, ids, context):
        return_picking_id = super(stock_consignation, self)._create_returns(cr, uid, ids, context)
        picking_obj = self.pool.get('stock.picking')
        move_obj = self.pool.get('stock.move')
        return_picking = picking_obj.browse(cr, uid, return_picking_id, context)
        
        #begin l10n_br specifics
        fiscal_operation_category_id = self.pool.get('l10n_br_account.fiscal.operation.category').search(cr, uid, [('name', 'ilike', 'Retorno Consignação')])[0] #TODO better if not hardcoded
        vals = {'fiscal_operation_category_id': fiscal_operation_category_id}
        vals.update(picking_obj.onchange_partner_in(cr, uid, context, return_picking.address_id.id, fiscal_operation_category_id, return_picking.company_id.id)['value'])
        print "return picking vals", vals
        picking_obj.write(cr, uid, [return_picking_id], vals)
        #end l10n_br specifics
        
        wf_service = netsvc.LocalService("workflow")
        wf_service.trg_validate(uid, 'stock.picking', return_picking_id, 'button_done', cr)
        sale_picking_id = picking_obj.copy(cr, uid, return_picking_id, {'name': 'sale of %s' % return_picking.name, 'type': 'out', 'invoice_state': '2binvoiced'})
        sale_picking = picking_obj.browse(cr, uid, sale_picking_id, context)
        
        #begin l10n_br specifics
        fiscal_operation_category_id = self.pool.get('l10n_br_account.fiscal.operation.category').search(cr, uid, [('name', 'ilike', 'Venda')])[0] #TODO better if not hardcoded
        vals = {'fiscal_operation_category_id': fiscal_operation_category_id}
        vals.update(picking_obj.onchange_partner_in(cr, uid, context, return_picking.address_id.id, fiscal_operation_category_id, return_picking.company_id.id)['value'])
        print "sale picking vals", vals
        picking_obj.write(cr, uid, [sale_picking_id], vals)
        #end l10n_br specifics
        
        order = sale_picking.sale_id
        for move in sale_picking.move_lines:
            move_obj.write(cr, uid, move.id, {
                                    'location_id': order.shop_id.warehouse_id.lot_stock_id.id,
                                    'location_dest_id': order.shop_id.warehouse_id.lot_output_id.id
                                    })
            
        picking_obj.draft_validate(cr, uid, [sale_picking_id], context)
        
        data = self.read(cr, uid, ids[0])
        if data['invoice_state'] != 'none':
            wiz_id = self.pool.get('stock.invoice.onshipping').create(cr, uid, {'journal_id': data['journal_id'], 'group': data['group'], 'type': 'in_invoice'})
            context['active_ids'] = [return_picking_id]
            self.pool.get('stock.invoice.onshipping').create_invoice(cr, uid, [wiz_id], context)
            
            wiz_id = self.pool.get('stock.invoice.onshipping').create(cr, uid, {'journal_id': data['journal_id'], 'group': data['group'], 'type': 'out_invoice'})
            context['active_ids'] = [sale_picking_id]
            self.pool.get('stock.invoice.onshipping').create_invoice(cr, uid, [wiz_id], context)

        
        return return_picking_id
    
    def fields_view_get(self, cr, uid, view_id=None, view_type='form', context=None, toolbar=False, submenu=False):
        res = super(stock_consignation, self).fields_view_get(cr, uid, view_id, view_type, context, toolbar, submenu)
        res['fields']['journal_id'] = {'string': 'Destination Journal', 'views': {}, 'required': True, 'relation': 'account.journal', 'selectable': True, 'type': 'many2one'}
        res['fields']['group'] = {'selectable': True, 'type': 'boolean', 'string': 'Group by partner', 'views': {}}
        res['arch'] = res['arch'].replace('</group>', """<field name="journal_id" /><field name="group" /></group>""")
        return res
    
stock_consignation()

# vim:expandtab:smartindent:tabstop=4:softtabstop=4:shiftwidth=4:

